Python bindings and command line tool to the Tricircle API
=========================================================

This is a client for `OpenStack Tricircle API`_. There's :doc:`a Python API <api>` (the
:mod:`tricircleclient` module), and a :doc:`command-line script <shell>`
(installed as :program:`tricircle`). Each implements the entire Tricircle API.

.. seealso::

    You may want to read the `Tricircle documentation`__ to get an idea of the
    concepts. By understanding the concepts this library and client should make
    more sense.

    __ https://docs.openstack.org/developer/tricircle/

.. _Tricircle: https://docs.openstack.org/developer/tricircle/

Contents:

.. toctree::
   :maxdepth: 2

   api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


